
.. DO NOT EDIT.
.. THIS FILE WAS AUTOMATICALLY GENERATED BY SPHINX-GALLERY.
.. TO MAKE CHANGES, EDIT THE SOURCE PYTHON FILE:
.. "source/auto_examples/plot_wind_rose.py"
.. LINE NUMBERS ARE GIVEN BELOW.

.. only:: html

    .. note::
        :class: sphx-glr-download-link-note

        Click :ref:`here <sphx_glr_download_source_auto_examples_plot_wind_rose.py>`
        to download the full example code

.. rst-class:: sphx-glr-example-title

.. _sphx_glr_source_auto_examples_plot_wind_rose.py:


=====================================================================
Example on how to plot winds and relative humidity from sounding data
=====================================================================

This is an example of how to display wind rose and barb timeseries
from multiple days worth of sounding data.

.. GENERATED FROM PYTHON SOURCE LINES 10-35



.. image:: /source/auto_examples/images/sphx_glr_plot_wind_rose_001.png
    :alt: act_datastream on 20060119, sonde_darwin on 20060119
    :class: sphx-glr-single-img


.. rst-class:: sphx-glr-script-out

 Out:

 .. code-block:: none

    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:392: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attributes = {k: var.getncattr(k) for k in var.ncattrs()}
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/backends/netCDF4_.py:425: DeprecationWarning: tostring() is deprecated. Use tobytes() instead.
      attrs = FrozenDict((k, self.ds.getncattr(k)) for k in self.ds.ncattrs())
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/core/variable.py:125: DeprecationWarning: Using a DataArray object to construct a variable is ambiguous, please extract the data using the .data property. This will raise a TypeError in 0.19.0.
      warnings.warn(
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/xarray/core/variable.py:125: DeprecationWarning: Using a DataArray object to construct a variable is ambiguous, please extract the data using the .data property. This will raise a TypeError in 0.19.0.
      warnings.warn(
    /Users/atheisen/Code/ACT/act/plotting/plot.py:82: UserWarning: Could not discern datastreamname and dict or tuple were not provided. Using defaultname of act_datastream!
      warnings.warn(("Could not discern datastream" +
    /Users/atheisen/Code/ACT/act/plotting/TimeSeriesDisplay.py:942: MatplotlibDeprecationWarning: shading='flat' when X and Y have the same dimensions as C is deprecated since 3.3.  Either specify the corners of the quadrilaterals with X and Y, or pass shading='auto', 'nearest' or 'gouraud', or set rcParams['pcolor.shading'].  This will become an error two minor releases later.
      mesh = self.axes[subplot_index].pcolormesh(
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/dask/core.py:121: RuntimeWarning: invalid value encountered in sin
      return func(*(_execute_task(a, cache) for a in args))
    /Users/atheisen/opt/anaconda3/lib/python3.8/site-packages/dask/core.py:121: RuntimeWarning: invalid value encountered in cos
      return func(*(_execute_task(a, cache) for a in args))






|

.. code-block:: default


    import act
    import numpy as np

    from matplotlib import pyplot as plt

    sonde_ds = act.io.armfiles.read_netcdf(
        act.tests.sample_files.EXAMPLE_TWP_SONDE_WILDCARD)

    WindDisplay = act.plotting.WindRoseDisplay(sonde_ds, figsize=(8, 10), subplot_shape=(2,))
    WindDisplay.plot('deg', 'wspd',
                     spd_bins=np.linspace(0, 25, 5), num_dirs=30,
                     tick_interval=2, subplot_index=(0,))


    BarbDisplay = act.plotting.TimeSeriesDisplay(
        {'sonde_darwin': sonde_ds}, figsize=(10, 5))
    WindDisplay.put_display_in_subplot(BarbDisplay, subplot_index=(1,))
    BarbDisplay.plot_time_height_xsection_from_1d_data('rh', 'pres',
                                                       cmap='coolwarm_r',
                                                       vmin=0, vmax=100,
                                                       num_time_periods=25)
    BarbDisplay.plot_barbs_from_spd_dir('deg', 'wspd', 'pres',
                                        num_barbs_x=20)
    plt.show()


.. rst-class:: sphx-glr-timing

   **Total running time of the script:** ( 0 minutes  1.704 seconds)


.. _sphx_glr_download_source_auto_examples_plot_wind_rose.py:


.. only :: html

 .. container:: sphx-glr-footer
    :class: sphx-glr-footer-example



  .. container:: sphx-glr-download sphx-glr-download-python

     :download:`Download Python source code: plot_wind_rose.py <plot_wind_rose.py>`



  .. container:: sphx-glr-download sphx-glr-download-jupyter

     :download:`Download Jupyter notebook: plot_wind_rose.ipynb <plot_wind_rose.ipynb>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
